@@ -2,7 +2,10 @@ library(ggiraph)
 library(shinycssloaders)
 
 shinyUI(
-  navbarPage("EQ-5D",
+  navbarPage(title="EQ-5D",
+             header=singleton(tags$head(
+               tags$style(type="text/css", "text {font-family: sans-serif}")
+               )),
     
     tabPanel("Data", tags$style(HTML("
               .col-sm-4, .col-sm-8 {margin-top:5px;}")),
@@ -61,13 +64,15 @@ shinyUI(
       div(style="padding-left:20%;padding-right:20%;",
         h4("How do I format my data for uploading?"),
         p("Data to be uploaded should be in either a Microsoft Excel (xlsx/xls) file or 
-          a CSV file. The file should be a minimum of five columns and must contain a 
-          header row with the labels MO, SC, UA, PD and AD (representing the 
-          dimensions Mobility, Self-care, Usual activities, Pain/discomfort and 
-          Anxiety/depression). Additional columns can be included in the file. 
-          Non-numeric columns can be used for grouping data in the plots tab. An 
-          example file can be downloaded " , 
+          a CSV file. The file should contain either a header row with the labels 
+          MO, SC, UA, PD and AD (representing the dimensions Mobility, Self-care, 
+          Usual activities, Pain/discomfort and Anxiety/depression) or use the column 
+          label 'State' with the scores encoded in five digit format. Additional columns 
+          can be included in the file as can been seen in the image below. Both formats 
+          in the image will produce the same results. Non-numeric columns can be used for 
+          grouping data in the plots tab. An example file can be downloaded " , 
           a("here", href="data/eq5d3l_example.xlsx", target="_blank"), "."),
+        div(img(src="images/shiny_app_excel_scores.png", width="75%"), style="text-align:center"),
         h4("I've uploaded my data. What do I do now?"),
         p("Once a file of EQ-5D dimension scores has been successfully uploaded the 
           correct EQ-5D version and value set need to be selected from side bar for 
@@ -101,7 +106,6 @@ shinyUI(
           can be found ', 
           a(href='https://github.com/fragla/eq5d/blob/master/DESCRIPTION', ' here'), '.')))
       )
-    ),
-    tags$head( tags$style(type="text/css", "text {font-family: sans-serif}"))
+    )
   )
 )
